# PYFER

## Encrypt and Decrypt Strings

Pyfer is a simple encryption and decryption tool built in Python. 

![pyfer_cover](aux/rm_cover.jpg)

### Features

With this little library you can do the following:

 - Encrypt and decrypt strings
 - Use one of three available encryption modes, each using a different ciphertext alphabet
 - Generate random digit keys

### Installation

It's as easy as `pip install pyfer`!

### Quickstart

Have a look at the demo [here](https://github.com/elbydata/pyfer/blob/master/demos/demo.ipynb)!

### Documentation

Documentation is currently available in the form of docstrings.

### Requirements and Dependencies

Please see the `requirements.txt` file for all requirements and dependencies.
 
### Support

The source code is available [here](https://github.com/elbydata/pyfer/tree/master/pyfer).
Please direct any queries to info@elbydata.com.

### License

The project is licensed under the MIT license.